import { SourceDemoBuffer } from './buffer.js';
import { SourceDemo } from './demo.js';
import { CmdInfo } from './types/CmdInfo.js';
import { SendTable, ServerClassInfo } from './types/DataTables.js';
import { NetMessage } from './types/NetMessages.js';
import { StringTable as StringTableType } from './types/StringTables.js';
import { UserCmd as UserCmdType } from './types/UserCmd.js';
export declare class Message {
    type: number;
    tick?: number;
    slot?: number;
    constructor(type: number);
    static default(type: number): Message;
    getType(): number;
    getName(): string;
    getTick(): number | undefined;
    getSlot(): number | undefined;
    setTick(tick: number): this;
    setSlot(slot: number): this;
    read(_buf: SourceDemoBuffer, _demo: SourceDemo): Message;
    write(_buf: SourceDemoBuffer, _demo: SourceDemo): Message;
}
export declare class Packet extends Message {
    packets?: NetMessage[];
    cmdInfo?: CmdInfo[];
    inSequence?: number;
    outSequence?: number;
    data?: SourceDemoBuffer;
    restData?: SourceDemoBuffer;
    constructor(type: number);
    findPacket<T extends NetMessage>(type: (new (type: number) => T) | ((packet: NetMessage) => boolean)): T | undefined;
    findPackets<T extends NetMessage>(type: (new (type: number) => T) | ((packet: NetMessage) => boolean)): T[];
    read(buf: SourceDemoBuffer, demo: SourceDemo): this;
    write(buf: SourceDemoBuffer): this;
    [Symbol.iterator](): Generator<NetMessage, void, unknown>;
}
export declare class SignOn extends Packet {
}
export declare class SyncTick extends Message {
    read(): this;
    write(): this;
}
export declare class ConsoleCmd extends Message {
    command?: string;
    read(buf: SourceDemoBuffer): this;
    write(buf: SourceDemoBuffer): this;
}
export declare class UserCmd extends Message {
    cmd?: number;
    data?: SourceDemoBuffer;
    userCmd?: UserCmdType;
    restData?: SourceDemoBuffer;
    read(buf: SourceDemoBuffer): this;
    write(buf: SourceDemoBuffer): this;
}
export declare class DataTable extends Message {
    data?: SourceDemoBuffer;
    dataTable?: {
        tables: SendTable[];
        serverClasses: ServerClassInfo[];
        restData?: SourceDemoBuffer;
    };
    read(buf: SourceDemoBuffer): this;
    write(buf: SourceDemoBuffer): this;
}
export declare class Stop extends Message {
    restData?: SourceDemoBuffer;
    read(buf: SourceDemoBuffer): this;
    write(buf: SourceDemoBuffer): this;
}
export declare class CustomData extends Message {
    unk?: number;
    data?: SourceDemoBuffer;
    read(buf: SourceDemoBuffer): this;
    write(buf: SourceDemoBuffer): this;
}
export declare class StringTable extends Message {
    data?: SourceDemoBuffer;
    stringTables?: StringTableType[];
    restData?: SourceDemoBuffer;
    read(buf: SourceDemoBuffer): this;
    write(buf: SourceDemoBuffer): this;
}
export declare const DemoMessages: {
    NewEngine: (typeof Packet | typeof SyncTick | typeof ConsoleCmd | typeof DataTable | typeof Stop | typeof CustomData | undefined)[];
    OldEngine: (typeof Packet | typeof SyncTick | typeof ConsoleCmd | typeof DataTable | typeof Stop | undefined)[];
    Message: typeof Message;
    SignOn: typeof SignOn;
    Packet: typeof Packet;
    SyncTick: typeof SyncTick;
    ConsoleCmd: typeof ConsoleCmd;
    UserCmd: typeof UserCmd;
    DataTable: typeof DataTable;
    Stop: typeof Stop;
    CustomData: typeof CustomData;
    StringTable: typeof StringTable;
};
